pub struct ExitInfo {
pub exit_code: i32,
pub message: Option<String>,
}Expand description
Returned by a subcommand plugin from hm_subcommand_run. The host
translates exit_code into the process exit code.
Fields
exit_code: i32message: Option<String>Optional message written to stderr by the host before exit.
Used for the rare case where the plugin wants to add context
beyond the bytes it already streamed via hm_log.