Module events

Module events 

Build-time events. Produced by the orchestrator (host) and fanned out to output formatters, lifecycle hooks, and (via the host re-broadcast of hm_emit_step_log) any subscriber.

Structs

PlanSummary
Compact summary of the resolved IR included in BuildStart. Lets output formatters print a header without needing the full pipeline.

Enums

BuildEvent
StdStream