pub struct ArchiveId(pub Uuid);Expand description
Opaque archive handle. The plugin streams bytes via
hm_archive_read(id, offset, max).
Tuple Fields
0: UuidTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ArchiveId
impl<'de> Deserialize<'de> for ArchiveId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArchiveId
impl JsonSchema for ArchiveId
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
impl Copy for ArchiveId
impl Eq for ArchiveId
impl StructuralPartialEq for ArchiveId