pub struct ArtifactRef {
pub key: String,
pub mime: String,
pub size_bytes: u64,
}Fields
key: Stringmime: Stringsize_bytes: u64Trait Implementations
Sourceimpl Clone for ArtifactRef
impl Clone for ArtifactRef
Sourcefn clone(&self) -> ArtifactRef
fn clone(&self) -> ArtifactRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactRef
impl Debug for ArtifactRef
Sourceimpl<'de> Deserialize<'de> for ArtifactRef
impl<'de> Deserialize<'de> for ArtifactRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArtifactRef
impl JsonSchema for ArtifactRef
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArtifactRef
impl PartialEq for ArtifactRef
Sourcefn eq(&self, other: &ArtifactRef) -> bool
fn eq(&self, other: &ArtifactRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ArtifactRef
impl Serialize for ArtifactRef
impl Eq for ArtifactRef
impl StructuralPartialEq for ArtifactRef