pub struct SnapshotRef(pub String);Expand description
Opaque snapshot reference. For the docker plugin this is an image tag; other plugins are free to encode their own format. The host never inspects the contents.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for SnapshotRef
impl Clone for SnapshotRef
Sourcefn clone(&self) -> SnapshotRef
fn clone(&self) -> SnapshotRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapshotRef
impl Debug for SnapshotRef
Sourceimpl<'de> Deserialize<'de> for SnapshotRef
impl<'de> Deserialize<'de> for SnapshotRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for SnapshotRef
impl Hash for SnapshotRef
Sourceimpl JsonSchema for SnapshotRef
impl JsonSchema for SnapshotRef
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl PartialEq for SnapshotRef
impl PartialEq for SnapshotRef
Sourcefn eq(&self, other: &SnapshotRef) -> bool
fn eq(&self, other: &SnapshotRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SnapshotRef
impl Serialize for SnapshotRef
impl Eq for SnapshotRef
impl StructuralPartialEq for SnapshotRef