pub struct StepResult {
pub exit_code: i32,
pub committed_snapshot: Option<SnapshotRef>,
pub artifacts: Vec<ArtifactRef>,
}Fields
exit_code: i32committed_snapshot: Option<SnapshotRef>Some(tag) when the executor wrote a snapshot for this step
(typically only on CacheDecision::MissBuildAs).
artifacts: Vec<ArtifactRef>Trait Implementations
Sourceimpl Clone for StepResult
impl Clone for StepResult
Sourcefn clone(&self) -> StepResult
fn clone(&self) -> StepResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StepResult
impl Debug for StepResult
Sourceimpl<'de> Deserialize<'de> for StepResult
impl<'de> Deserialize<'de> for StepResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StepResult
impl JsonSchema for StepResult
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StepResult
impl PartialEq for StepResult
Sourcefn eq(&self, other: &StepResult) -> bool
fn eq(&self, other: &StepResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StepResult
impl Serialize for StepResult
impl Eq for StepResult
impl StructuralPartialEq for StepResult