pub struct HookEvent {
pub event: BuildEvent,
pub phase: HookPhase,
}Expand description
Hook entry-point input. The host wraps a BuildEvent and tells
the plugin which phase this call is.
Fields
event: BuildEventphase: HookPhaseTrait Implementations
Sourceimpl<'de> Deserialize<'de> for HookEvent
impl<'de> Deserialize<'de> for HookEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HookEvent
impl JsonSchema for HookEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl Eq for HookEvent
impl StructuralPartialEq for HookEvent