pub struct DockerCommitArgs {
pub container_id: String,
pub tag: String,
}Expand description
Host-fn argument struct for hm_docker_commit.
Fields
container_id: Stringtag: StringTrait Implementations
Sourceimpl Clone for DockerCommitArgs
impl Clone for DockerCommitArgs
Sourcefn clone(&self) -> DockerCommitArgs
fn clone(&self) -> DockerCommitArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DockerCommitArgs
impl Debug for DockerCommitArgs
Sourceimpl<'de> Deserialize<'de> for DockerCommitArgs
impl<'de> Deserialize<'de> for DockerCommitArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DockerCommitArgs
impl JsonSchema for DockerCommitArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DockerCommitArgs
impl PartialEq for DockerCommitArgs
Sourcefn eq(&self, other: &DockerCommitArgs) -> bool
fn eq(&self, other: &DockerCommitArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DockerCommitArgs
impl Serialize for DockerCommitArgs
impl Eq for DockerCommitArgs
impl StructuralPartialEq for DockerCommitArgs