pub struct DockerExtractArgs {
pub container_id: String,
pub archive_id: ArchiveId,
pub workdir: String,
}Expand description
Host-fn argument struct for hm_docker_extract_workspace.
Fields
container_id: Stringarchive_id: ArchiveIdworkdir: StringTrait Implementations
Sourceimpl Clone for DockerExtractArgs
impl Clone for DockerExtractArgs
Sourcefn clone(&self) -> DockerExtractArgs
fn clone(&self) -> DockerExtractArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DockerExtractArgs
impl Debug for DockerExtractArgs
Sourceimpl<'de> Deserialize<'de> for DockerExtractArgs
impl<'de> Deserialize<'de> for DockerExtractArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DockerExtractArgs
impl JsonSchema for DockerExtractArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DockerExtractArgs
impl PartialEq for DockerExtractArgs
Sourcefn eq(&self, other: &DockerExtractArgs) -> bool
fn eq(&self, other: &DockerExtractArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DockerExtractArgs
impl Serialize for DockerExtractArgs
impl Eq for DockerExtractArgs
impl StructuralPartialEq for DockerExtractArgs