pub struct LoopbackHandle(pub u64);Expand description
Opaque handle returned by hm_spawn_loopback. Bound to the plugin
instance.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for LoopbackHandle
impl Clone for LoopbackHandle
Sourcefn clone(&self) -> LoopbackHandle
fn clone(&self) -> LoopbackHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoopbackHandle
impl Debug for LoopbackHandle
Sourceimpl<'de> Deserialize<'de> for LoopbackHandle
impl<'de> Deserialize<'de> for LoopbackHandle
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for LoopbackHandle
impl Hash for LoopbackHandle
Sourceimpl JsonSchema for LoopbackHandle
impl JsonSchema for LoopbackHandle
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl PartialEq for LoopbackHandle
impl PartialEq for LoopbackHandle
Sourcefn eq(&self, other: &LoopbackHandle) -> bool
fn eq(&self, other: &LoopbackHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LoopbackHandle
impl Serialize for LoopbackHandle
impl Copy for LoopbackHandle
impl Eq for LoopbackHandle
impl StructuralPartialEq for LoopbackHandle