pub struct SubcommandSpec {
pub verb: String,
pub about: String,
pub args_schema: ClapJson,
pub subcommands: Vec<Self>,
}Fields
verb: StringTop-level verb under hm. Two plugins may not claim the
same verb.
about: Stringargs_schema: ClapJsonClap-shaped JSON for argument parsing (the host re-parses on
the plugin’s behalf via clap).
subcommands: Vec<Self>Trait Implementations
Sourceimpl Clone for SubcommandSpec
impl Clone for SubcommandSpec
Sourcefn clone(&self) -> SubcommandSpec
fn clone(&self) -> SubcommandSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubcommandSpec
impl Debug for SubcommandSpec
Sourceimpl<'de> Deserialize<'de> for SubcommandSpec
impl<'de> Deserialize<'de> for SubcommandSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubcommandSpec
impl JsonSchema for SubcommandSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SubcommandSpec
impl PartialEq for SubcommandSpec
Sourcefn eq(&self, other: &SubcommandSpec) -> bool
fn eq(&self, other: &SubcommandSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SubcommandSpec
impl Serialize for SubcommandSpec
impl Eq for SubcommandSpec
impl StructuralPartialEq for SubcommandSpec