Module subcommand

Module subcommand 

Wire type for subcommand invocations.

Structs

SubcommandInput
Carried into the plugin’s subcommand entry point. The host has already parsed argv on the plugin’s behalf using the schema the plugin declared in its manifest.