Wire type for subcommand invocations.
Structs
- Subcommand
Input - Carried into the plugin’s subcommand entry point. The host has already parsed argv on the plugin’s behalf using the schema the plugin declared in its manifest.
Wire type for subcommand invocations.